@@ -1,4 +1,4 @@
-"matSums" <-
+`matSums` <-
 function (lis) {
     out <- array(data = 0, dim = dim(lis[[1]]))
     for (i in seq(along = lis))
